<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="returnTable"
      >
        <template #toolbar></template>
      </ttable>

      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchListReturn, delReturn} from '@/api/warehouse/return'
  import {loadStockInCode} from '@/api/warehouse/stockincode'
  import TableForm from './return-form'
  import {mapGetters} from 'vuex'
  import ttable from '@/views/common/ztt-table'

  export default {
    data() {
      return {
        ajaxFun:fetchListReturn,
        receiveTypes: [],
        multipleSelection: [],
        isShowQuery: false,
        uploadInfo: {//是否展示上传EXCEL以及对应的url
          isShow: false,
          url: ''
        },
        prelang: "operation",
        options: {
          height: 300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border: true,//是否有纵向边框
          lazy: false,//是否需要懒加载
          fit: true,//列的宽度是否自撑开
          multiSelect: true,//
          seqNo: true,
          isShowHide: true,//是否显示显影按钮
          isSearch: false,//高级查询按钮
          defaultOrderBy:{column:'id',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data: [],
          // 标题
          column: [
            {minWidth:'100',prop:"returnNo",label:"退库单号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',render:{fun:this.addOrUpdateHandle}},
            {minWidth:'100',prop: "applyDate",label:"申请时间",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange'},
            {minWidth:'100',prop: "applyUser",label:"申请人",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            {minWidth:'100',prop: "returnType",label:"退库类型",sort: true,isTrue:true,formatter:this.formatReceiveType,isSearch:true,searchInfoType:'select',optList:() => {return this.receiveTypes}},
            {minWidth:'120',prop: "status",label:"状态",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            {minWidth:'120',prop: "remark",label:"备注",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
          ],
          toolbar: [
            {
              text: '新增',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ],
          operator: [
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle,
              show:{
                val:['未下发'],
                key:'status'
              }
            }
          ],
          operatorConfig: {
            fixed: 'right',
            label: '操作',
            width: 120,
            minWidth: 120
          },
        },
        addOrUpdateVisible: false
      }
    },
    components: {
      ttable,
      TableForm
    },
    created() {
      this.initReceiveTypes()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取入库类型
      initReceiveTypes() {
        loadStockInCode(Object.assign({
          stockCodeType: 0,
          stockCodeStatus: 1
        })).then(res => {
          this.receiveTypes = JSON.parse(JSON.stringify(res.data.data).replace(/id/g, 'value').replace(/stockCodeName/g, 'label'))
        })
      },
      // 获取数据列表
      getData () {
        if(this.$refs.returnTable !==undefined){
          this.$refs.returnTable.getDataList();
        }

      },
      // 新增 / 修改
      addOrUpdateHandle(row) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row ? row.id : row)
        })
      },
      // 删除
      deleteHandle(row) {
        this.$confirm('是否确认删除', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delReturn(row ? row.id : row)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      },
      // 表格字段格式化
      formatReceiveType(row, column, cellValue) {
        for (let i = 0, len = this.receiveTypes.length; i < len; i++) {
          if (cellValue == this.receiveTypes[i].value) {
            return this.receiveTypes[i].label
          }
        }
      },
      // table自带事件
      handleSelectionChange(val) {
        this.multipleSelection = val
      },
    }
  }
</script>
